matminer.featurizers.composition.tests package — matminer 0.7.0 documentation

# matminer.featurizers.composition.tests package

## Submodules

## matminer.featurizers.composition.tests.base module

class `matminer.featurizers.composition.tests.base.` `CompositionFeaturesTest`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

## matminer.featurizers.composition.tests.test_alloy module

class `matminer.featurizers.composition.tests.test_alloy.` `AlloyFeaturizersTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_WenAlloys`()
  `test_miedema_all`()
  `test_miedema_ss`()
  `test_yang`()

## matminer.featurizers.composition.tests.test_composite module

class `matminer.featurizers.composition.tests.test_composite.` `CompositeFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_elem`()
  `test_elem_deml`()
  `test_elem_matminer`()
  `test_elem_matscholar_el`()
  `test_elem_megnet_el`()
  `test_fere_corr`()
  `test_meredig`()

## matminer.featurizers.composition.tests.test_element module

class `matminer.featurizers.composition.tests.test_element.` `ElementFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_band_center`()
  `test_fraction`()
  `test_stoich`()
  `test_tm_fraction`()

## matminer.featurizers.composition.tests.test_ion module

class `matminer.featurizers.composition.tests.test_ion.` `IonFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_cation_properties`()
  `test_elec_affin`()
  `test_en_diff`()
  `test_ionic`()
  `test_is_ionic`()

    Test checking whether a compound is ionic

  `test_oxidation_states`()

## matminer.featurizers.composition.tests.test_orbital module

class `matminer.featurizers.composition.tests.test_orbital.` `OrbitalFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_atomic_orbitals`()
  `test_valence`()

## matminer.featurizers.composition.tests.test_packing module

class `matminer.featurizers.composition.tests.test_packing.` `PackingFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_ape`()

## matminer.featurizers.composition.tests.test_thermo module

class `matminer.featurizers.composition.tests.test_thermo.` `ThermoFeaturesTest`(methodName='runTest')

  Bases: `matminer.featurizers.composition.tests.base.CompositionFeaturesTest`

  `test_cohesive_energy`()
  `test_cohesive_energy_mp`()

## Module contents